@@ -9,7 +9,7 @@
 #
 # ABSTRACT: Work on the configuration model of an application
 
-package App::Cme::Command::meta 2.017;
+package App::Cme::Command::meta 2.018;
 
 use strict ;
 use warnings ;
@@ -353,7 +353,7 @@ sub _edit {
     $mw->optionAdd('*BorderWidth' => 1);
 
     my $cmu = $mw->ConfigModelEditUI(
-        -root       => $meta_root,
+        -instance   => $meta_root->instance,
         -store_sub  => $write_sub,
         -model_name => $root_model,
         -cm_lib_dir => $cm_lib_dir
@@ -405,7 +405,7 @@ App::Cme::Command::meta - Work on the configuration model of an application
 
 =head1 VERSION
 
-version 2.017
+version 2.018
 
 =head1 SYNOPSIS
 
